import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

import { isNodeEmpty, Placeholder } from 'redaktilo-plugin-helpers';

import { EMPHASIS_DEFINITIONS, EMPHASIS_TAG_NAME } from './constants';

import styles from './Emphasis.css';

const Emphasis = ({
  className,
  EMPHASIS_TAG = EMPHASIS_TAG_NAME,
  ...attributes
}) => ({ children, element } = {}) => {
  if (element.type === EMPHASIS_DEFINITIONS.type) {
    const { placeholder, ...restOfAttributes } = attributes;

    if (placeholder && isNodeEmpty(element)) {
      return (
        <EMPHASIS_TAG
          {...restOfAttributes}
          data-editor-plugin={EMPHASIS_DEFINITIONS.type}
          className={className}
        >
          {Placeholder(children, className, placeholder)}
        </EMPHASIS_TAG>
      );
    } else {
      return (
        <EMPHASIS_TAG
          {...restOfAttributes}
          data-editor-plugin={EMPHASIS_DEFINITIONS.type}
          className={cx(className, styles.emphasis)}
        >
          {children}
        </EMPHASIS_TAG>
      );
    }
  }
};

Emphasis.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  EMPHASIS_TAG: PropTypes.node,
};

export { Emphasis };
