/** @jsx h */

// eslint-disable-next-line import/no-internal-modules
import { renderEditor } from 'redaktilo-spec-helpers/render';

// eslint-disable-next-line import/no-internal-modules
import { Plugin as EmphasisPlugin } from '..';

const initialValue = {
  children: [
    {
      type: 'emphasis',
      children: [
        {
          text: 'some',
        },
      ],
    },
    {
      type: 'paragraph',
      children: [{ text: 'paragraph' }],
    },
    {
      type: 'paragraph',
      children: [{ text: '' }],
    },
    {
      type: 'emphasis',
      children: [
        {
          text: 'and emphasis',
        },
      ],
    },
  ],
};

describe('EmphasisPlugin', () => {
  window.getSelection = jest.fn();

  it('renders correctly', () => {
    const { container } = renderEditor({
      plugins: [EmphasisPlugin()],
      initialValue,
    });

    expect(container).toMatchSnapshot();
  });

  it('renders correctly with custom className', () => {
    const { container } = renderEditor({
      plugins: [EmphasisPlugin({ className: '#myClassName' })],
      initialValue,
    });

    expect(container).toMatchSnapshot();
  });

  it('renders emphasis with a placeholder', () => {
    const emphasis = EmphasisPlugin({ placeholder: 'Emphasise something' });
    const { container } = renderEditor({
      plugins: [emphasis],
      initialValue: {
        children: [
          {
            type: 'emphasis',
            children: [
              {
                text: '',
              },
            ],
          },
        ],
      },
    });

    expect(container).toMatchSnapshot();
  });
});
